@@ -7,6 +7,7 @@ import gradio as gr
 import mteb
 from build.lib.mteb.benchmarks.benchmarks import MTEB_multilingual
 from mteb import Benchmark
+from mteb.benchmarks.benchmarks import MTEB_multilingual
 
 DEFAULT_BENCHMARK_NAME = MTEB_multilingual.name
 
@@ -64,6 +65,7 @@ BENCHMARK_ENTRIES = [
                         "MTEB(pol, v1)",
                         "MTEB(rus, v1)",
                         "MTEB(fas, v1)",
+                        "VN-MTEB (vie, v1)",
                     ]
                 )
                 + [MenuEntry("Other", mteb.get_benchmarks(["MTEB(eng, v1)"]))],
@@ -191,5 +193,4 @@ def _render_benchmark_item(
 if __name__ == "__main__":
     with gr.Blocks() as b:
         selector = make_selector(BENCHMARK_ENTRIES)
-
     b.launch()
