@@ -21,19 +21,21 @@ class AskUbuntuDupQuestions(AbsTaskReranking):
         eval_langs=["eng-Latn"],
         main_score="map",
         date=None,
-        domains=None,
+        domains=["Programming", "Web"],
         task_subtypes=None,
         license=None,
-        annotations_creators=None,
-        dialect=None,
-        sample_creation=None,
+        annotations_creators="human-annotated",
+        dialect=[],
+        sample_creation="found",
         prompt="Retrieve duplicate questions from AskUbuntu forum",
-        bibtex_citation="""@article{wang-2021-TSDAE,
-    title = "TSDAE: Using Transformer-based Sequential Denoising Auto-Encoderfor Unsupervised Sentence Embedding Learning",
-    author = "Wang, Kexin and Reimers, Nils and  Gurevych, Iryna", 
-    journal= "arXiv preprint arXiv:2104.06979",
-    month = "4",
-    year = "2021",
-    url = "https://arxiv.org/abs/2104.06979",
-}""",
+        bibtex_citation=r"""
+@article{wang-2021-TSDAE,
+  author = {Wang, Kexin and Reimers, Nils and  Gurevych, Iryna},
+  journal = {arXiv preprint arXiv:2104.06979},
+  month = {4},
+  title = {TSDAE: Using Transformer-based Sequential Denoising Auto-Encoderfor Unsupervised Sentence Embedding Learning},
+  url = {https://arxiv.org/abs/2104.06979},
+  year = {2021},
+}
+""",
     )
