@@ -20,19 +20,21 @@ class StackOverflowDupQuestions(AbsTaskReranking):
         eval_splits=["test"],
         eval_langs=["eng-Latn"],
         main_score="map",
-        date=None,
-        domains=None,
-        task_subtypes=None,
-        license=None,
-        annotations_creators=None,
-        dialect=None,
-        sample_creation=None,
+        date=("2014-01-21", "2018-01-01"),
+        domains=["Written", "Blog", "Programming"],
+        task_subtypes=["Question answering"],
+        license="cc-by-nc-sa-4.0",
+        annotations_creators="derived",
+        dialect=[],
+        sample_creation="found",
         prompt="Retrieve duplicate questions from StackOverflow forum",
-        bibtex_citation="""@article{Liu2018LinkSOAD,
-  title={LinkSO: a dataset for learning to retrieve similar question answer pairs on software development forums},
-  author={Xueqing Liu and Chi Wang and Yue Leng and ChengXiang Zhai},
-  journal={Proceedings of the 4th ACM SIGSOFT International Workshop on NLP for Software Engineering},
-  year={2018},
-  url={https://api.semanticscholar.org/CorpusID:53111679}
-}""",
+        bibtex_citation=r"""
+@article{Liu2018LinkSOAD,
+  author = {Xueqing Liu and Chi Wang and Yue Leng and ChengXiang Zhai},
+  journal = {Proceedings of the 4th ACM SIGSOFT International Workshop on NLP for Software Engineering},
+  title = {LinkSO: a dataset for learning to retrieve similar question answer pairs on software development forums},
+  url = {https://api.semanticscholar.org/CorpusID:53111679},
+  year = {2018},
+}
+""",
     )
