@@ -12,8 +12,11 @@ from .code.CodeTransOceanContestRetrieval import *
 from .code.CodeTransOceanDLRetrieval import *
 from .code.COIRCodeSearchNetRetrieval import *
 from .code.CosQARetrieval import *
+from .code.MBPPRetrieval import *
+from .code.HumanEvalRetrieval import *
 from .code.StackOverflowQARetrieval import *
 from .code.SyntheticText2SqlRetrieval import *
+from .code.WikiSQLRetrieval import *
 from .dan.DanFeverRetrieval import *
 from .dan.TV2Nordretrieval import *
 from .dan.TwitterHjerneRetrieval import *
@@ -29,6 +32,9 @@ from .eng.AILAStatutesRetrieval import *
 from .eng.AlphaNLIRetrieval import *
 from .eng.ARCChallengeRetrieval import *
 from .eng.ArguAnaRetrieval import *
+from .eng.BarExamQARetrieval import *
+from .eng.BillSumCARetrieval import *
+from .eng.BillSumUSRetrieval import *
 from .eng.BrightRetrieval import *
 from .eng.BuiltBenchRetrieval import *
 from .eng.ChemHotpotQARetrieval import *
@@ -51,6 +57,7 @@ from .eng.FaithDialRetrieval import *
 from .eng.FeedbackQARetrieval import *
 from .eng.FEVERRetrieval import *
 from .eng.FiQA2018Retrieval import *
+from .eng.GovReportRetrieval import *
 from .eng.HagridRetrieval import *
 from .eng.HellaSwagRetrieval import *
 from .eng.HotpotQARetrieval import *
@@ -138,6 +145,7 @@ from .multilingual.MultiLongDocRetrieval import *
 from .multilingual.NeuCLIR2022Retrieval import *
 from .multilingual.NeuCLIR2023Retrieval import *
 from .multilingual.PublicHealthQARetrieval import *
+from .multilingual.RuSciBenchRetrieval import *
 from .multilingual.StatcanDialogueDatasetRetrieval import *
 from .multilingual.WebFAQRetrieval import *
 from .multilingual.WikipediaRetrievalMultilingual import *
@@ -192,7 +200,31 @@ from .spa.SpanishPassageRetrievalS2S import *
 from .swe.SwednRetrieval import *
 from .swe.SweFaqRetrieval import *
 from .tur.TurHistQuad import *
+from .vie.ArguAnaVNRetrieval import *
+from .vie.ClimateFEVERVNRetrieval import *
+from .vie.CQADupstackAndroidVNRetrieval import *
+from .vie.CQADupstackGisVNRetrieval import *
+from .vie.CQADupstackMathematicaVNRetrieval import *
+from .vie.CQADupstackPhysicsVNRetrieval import *
+from .vie.CQADupstackProgrammersVNRetrieval import *
+from .vie.CQADupstackStatsVNRetrieval import *
+from .vie.CQADupstackTexVNRetrieval import *
+from .vie.CQADupstackUnixVNRetrieval import *
+from .vie.CQADupstackWebmastersVNRetrieval import *
+from .vie.CQADupstackWordpressVNRetrieval import *
+from .vie.DBPediaVNRetrieval import *
+from .vie.FEVERVNRetrieval import *
+from .vie.FiQA2018VNRetrieval import *
 from .vie.GreenNodeTableMarkdownRetrieval import *
+from .vie.HotpotQAVNRetrieval import *
+from .vie.MSMARCOVNRetrieval import *
+from .vie.NFCorpusVNRetrieval import *
+from .vie.NQVNRetrieval import *
+from .vie.QuoraVNRetrieval import *
+from .vie.SCIDOCSVNRetrieval import *
+from .vie.SciFactVNRetrieval import *
+from .vie.Touche2020VNRetrieval import *
+from .vie.TRECCOVIDVNRetrieval import *
 from .vie.VieQuADRetrieval import *
 from .vie.ZacLegalTextRetrieval import *
 from .zho.CMTEBRetrieval import *
