@@ -30,12 +30,14 @@ class SCIDOCS(AbsTaskRetrieval):
         annotations_creators=None,
         dialect=[],
         sample_creation="found",
-        bibtex_citation="""@inproceedings{specter2020cohan,
-  title={SPECTER: Document-level Representation Learning using Citation-informed Transformers},
-  author={Arman Cohan and Sergey Feldman and Iz Beltagy and Doug Downey and Daniel S. Weld},
-  booktitle={ACL},
-  year={2020}
-}""",
+        bibtex_citation=r"""
+@inproceedings{specter2020cohan,
+  author = {Arman Cohan and Sergey Feldman and Iz Beltagy and Doug Downey and Daniel S. Weld},
+  booktitle = {ACL},
+  title = {SPECTER: Document-level Representation Learning using Citation-informed Transformers},
+  year = {2020},
+}
+""",
         prompt={
             "query": "Given a scientific paper title, retrieve paper abstracts that are cited by the given paper"
         },
